@@ -62,6 +62,7 @@ static int act_keyctl_new_session(int argc, char *argv[]);
 static int act_keyctl_reject(int argc, char *argv[]);
 static int act_keyctl_reap(int argc, char *argv[]);
 static int act_keyctl_purge(int argc, char *argv[]);
+static int act_keyctl_invalidate(int argc, char *argv[]);
 
 const struct command commands[] = {
 	{ act_keyctl___version,	"--version",	"" },
@@ -71,6 +72,7 @@ const struct command commands[] = {
 	{ act_keyctl_clear,	"clear",	"<keyring>" },
 	{ act_keyctl_describe,	"describe",	"<keyring>" },
 	{ act_keyctl_instantiate, "instantiate","<key> <data> <keyring>" },
+	{ act_keyctl_invalidate,"invalidate",	"<key>" },
 	{ act_keyctl_link,	"link",		"<key> <keyring>" },
 	{ act_keyctl_list,	"list",		"<keyring>" },
 	{ act_keyctl_negate,	"negate",	"<key> <timeout> <keyring>" },
@@ -240,7 +242,7 @@ static int act_keyctl___version(int argc, char *argv[])
  */
 static char *grab_stdin(size_t *_size)
 {
-	static char input[65536 + 1];
+	static char input[1024 * 1024 + 1];
 	int n, tmp;
 
 	n = 0;
@@ -1552,6 +1554,25 @@ static int act_keyctl_purge(int argc, char *argv[])
 	return 0;
 }
 
+/*****************************************************************************/
+/*
+ * Invalidate a key
+ */
+static int act_keyctl_invalidate(int argc, char *argv[])
+{
+	key_serial_t key;
+
+	if (argc != 2)
+		format();
+
+	key = get_key_id(argv[1]);
+
+	if (keyctl_invalidate(key) < 0)
+		error("keyctl_invalidate");
+
+	return 0;
+}
+
 /*****************************************************************************/
 /*
  * parse a key identifier
@@ -1600,7 +1621,7 @@ static int dump_key_tree_aux(key_serial_t key, int depth, int more, int hex_key_
 	char *desc, type[255], pretty_mask[9];
 	int uid, gid, ret, n, dpos, rdepth, kcount = 0;
 
-	if (depth > 8)
+	if (depth > 8 * 4)
 		return 0;
 
 	/* find out how big this key's description is */
